Changelog
=========

.. currentmodule:: Flask-Tracy

Release 0.1.2
-------------

UPDATE - Added the status code, of the response, to the trace log.

Release 0.1.0
-------------

BUG - Returning correct header name in 400's (When the trace-client header is required)

Release 0.0a1
-------------

Initial release
